@@ -80,17 +80,21 @@ class ftpclient:
 				return C_NG
 
 	#Get remote dir list
-	def getRemoteDirData(self):
+	def getRemoteDirData(self,pattarn=""):
 		try:
 			self.dir_obj = []
-			self.ftpcon.retrlines("LIST",self.dir_obj.append)
+			if pattarn == "":
+				send_command = "LIST"
+			else:
+				send_command = "LIST " + pattarn
+			self.ftpcon.retrlines(send_command,self.dir_obj.append)
 			return C_OK
 		except Exception, e:
 			self.error_obj = e
 			return C_NG
 
 	#Get current remote dir
-	def getCurrentRemote_dir(self):
+	def getCurrentRemoteDir(self):
 		try:
 			self.msg_obj = []
 			self.msg_obj.append(self.ftpcon.pwd())
@@ -109,7 +113,7 @@ class ftpclient:
 			self.error_obj = e
 			return C_NG
 
-	#Get file
+	#Get file(BINARY MODE)
 	def getRemoteFile(self,remote_filename,local_filename):
 		try:
 			self.ftpcon.retrbinary("RETR " + remote_filename,open(local_filename,"wb").write)
@@ -120,7 +124,7 @@ class ftpclient:
 			self.error_obj = e
 			return C_NG
 	
-	#Put file
+	#Put file(BINARY MODE)
 	def putLocalFile(self,remote_filename,local_filename):
 		try:
 			localfile = open(local_filename,"rb")
@@ -237,6 +241,47 @@ class ftpclient:
 			self.error_obj = e
 			return C_NG
 
+	#Get local dir
+	def getCurrentLocalDir(self):
+		try:
+			self.msg_obj = []
+			self.msg_obj.append(os.getcwd())
+			return C_OK
+		except Exception, e:
+			self.error_obj = e
+			return C_NG
+	#Set pasv mode
+	def setPasvmode(self):
+		try:
+			self.ftpcon.set_pasv(True)
+			return C_OK
+		except Exception, e:
+			self.error_obj = e
+			return C_NG
+
+	#Get file(ASCII MODE)
+	def getRemoteFileAscii(self,remote_filename,local_filename):
+		try:
+			self.ftpcon.retrlines("RETR " + remote_filename,open(local_filename,"wb").write)
+			self.getRemoteDirData()
+			return C_OK
+		except Exception, e:
+			os.remove(local_filename)
+			self.error_obj = e
+			return C_NG
+	
+	#Put file(ASCII MODE)
+	def putLocalFileAscii(self,remote_filename,local_filename):
+		try:
+			localfile = open(local_filename,"rb")
+			self.ftpcon.storlines("STOR " + remote_filename,localfile)
+			localfile.close()
+			self.getRemoteDirData()
+			return C_OK
+		except Exception, e:
+			self.error_obj = e
+			return C_NG
+
 	#Class initial
 	def __init__(self):
 		self.hostname = ""
